@@ -111,7 +111,7 @@ class Storage:
 class instance_description:
     storage_root = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
     storage_region = """Cloud storage region for s3 and Google Cloud."""
-    _dbconfig = """Either "sqlite" or postgres connection string."""
+    url = """Either sqlite or postgres connection string."""
     name = """Instance name."""
     _schema = """Comma-separated string of schema modules. None if not set."""
 
@@ -124,16 +124,16 @@ def instance_from_storage(storage):
 class InstanceSettings:
     """Instance settings written during setup."""
 
+    name: str
+    """Instance name."""
     storage_root: Union[CloudPath, Path] = None  # None is just for init, can't be None
     """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""
     storage_region: Optional[str] = None
     """Cloud storage region for s3 and Google Cloud."""
-    _dbconfig: str = "sqlite"
-    """Either "sqlite" or postgres connection string."""
+    url: Optional[str] = None
+    """Either sqlite or postgres connection string."""
     _schema: str = ""
     """Comma-separated string of schema modules. Empty string if only core schema."""
-    _name: Optional[str] = None
-    """Instance name."""
     _session: Optional[sqm.Session] = None
 
     @property
@@ -164,8 +164,7 @@ class InstanceSettings:
 
         Is a CloudPath if on S3 or GS, otherwise a Path.
         """
-        filename = instance_from_storage(self.storage_root)  # type: ignore
-        return self.storage.key_to_filepath(f"{filename}.lndb")
+        return self.storage.key_to_filepath(f"{self.name}.lndb")
 
     @property
     def _sqlite_file_local(self) -> Path:
@@ -183,30 +182,30 @@ class InstanceSettings:
             # this seems to work even if there is an open connection to the cache file
             os.utime(cache_file, times=(cloud_mtime, cloud_mtime))
 
-    @property
-    def name(self) -> str:
-        """Name of LaminDB instance.
-
-        Every LaminDB instance corresponds to exactly one database.
-
-        The name is unique per instance owner.
-        """
-        if self._name:
-            return self._name
-        if self._dbconfig == "sqlite":
-            return instance_from_storage(self.storage_root)
-        else:
-            return self._dbconfig.split("/")[-1]
-
     @property
     def db(self) -> str:
         """Database URL."""
         # the great thing about cloudpathlib is that it downloads the
         # remote file to cache as soon as the time stamp is out of date
-        if self._dbconfig == "sqlite":
+        if self.url is None:
             return f"sqlite:///{self.storage.cloud_to_local(self._sqlite_file)}"
         else:
-            return self._dbconfig
+            return self.url
+
+    @property
+    def dialect(self):
+        if self.url is None or self.url.startswith("sqlite://"):
+            return "sqlite"
+        elif self.url.startswith("postgresql://"):
+            return "postgresql"
+        return None
+
+    @property
+    def _dbconfig(self):
+        # logger.warning("_dbconfig is deprecated and will be removed soon")
+        if self.dialect == "sqlite":
+            return "sqlite"
+        return self.url
 
     def db_engine(self, future=True):
         """Database engine."""
